@@ -4,11 +4,11 @@ Example Lambda handler function.
 import json
 
 
-def lambda_handler(event, context):
+def lambda_handler(event, context=None):
     return {
+        'body': json.dumps({'text': 'Hello from Lambda Gateway!'}),
+        'statusCode': 200,
         'headers': {
             'Content-Type': 'application/json',
         },
-        'statusCode': 200,
-        'body': json.dumps({'text': 'Hello from Lambda Gateway!'})
     }
